<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Overenie bolo úspešné</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Overte svoje Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Zariadenie nie je dostupné!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Overte svoj odtlačok prsta</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Overenie bolo úspešné</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Overenie bolo úspešné</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Overte svoje Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Overenie bolo úspešné</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávaju %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Chybné heslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Obnoviť heslo</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zabudli ste heslo?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Obnoviť heslo</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zabudli ste heslo?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Overenie bolo úspešné</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Nesprávny PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Zadajte svoj PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Účet</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Vaše heslo vyprší za %d deň, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dni, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dní, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dní, zmeňte si ho prosím včas</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Platnosť hesla vypršala, zmeňte ho prosím</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Nesprávny účet</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Chybné heslo</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zamknúť obrazovku</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Zlyhalo zamknutie obrazovky</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Časový limit overenia odtlačku prsta vypršal. Prosím zadajte heslo ručne</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Zlyhalo porovnanie odtlačkov prstov</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Vyššie uvedení užívatelia sú stále prihlásení a údaje sa stratia v dôsledku vypnutia, ste si istí, že ich chcete vypnúť?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Vyššie uvedení užívatelia sú stále prihlásení a údaje sa stratia v dôsledku reštartu, ste si istí, že chcete reštartovať?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernácia</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Prepnúť užívateľa</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Prepnúť systém</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Spustenie systémového monitora</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Programy bránia vypnutiu počítača a nútené vypnutie môže spôsobiť stratu údajov.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Ak chcete program ukončiť, kliknite na tlačidlo Zrušiť a potom program zatvorte.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Programy bránia počítaču v reštartovaní a nútené reštartovanie môže spôsobiť stratu údajov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Programy bránia pozastaveniu počítača a nútené pozastavenie môže spôsobiť stratu údajov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Programy bránia prechodu počítača do režimu dlhodobého spánku a nútený režim dlhodobého spánku môže spôsobiť stratu údajov.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Programy bránia počítaču v odhlásení a nútené odhlásenie môže spôsobiť stratu údajov.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernácia</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Určite chcete vypnúť?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Naozaj chcete reštartovať?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Určite sa chcete odhlásiť?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Zapnúť</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Vypnúť</translation>
    </message>
</context>
</TS>